'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/*!
 * Linkifier Component
 * Copyright 2016 Pedro Ladaria <pedro.ladaria@gmail.com>
 * License: MIT
 */
var React = require('react');
var RE_CAPTURE_URLS = require('./regexp-capture-urls.js');
var RE_EMAIL_CHECK = require('./regexp-email-check.js');

var RE_HAS_SCHEME = /^\w+:/i;
var defaultScheme = 'http://';
var defaultKeyBase = 'linkifier';

var addSchemeIfNeeded = function addSchemeIfNeeded(url) {
    if (RE_EMAIL_CHECK.test(url)) {
        return 'mailto:' + url;
    }
    if (RE_HAS_SCHEME.test(url)) {
        return url;
    }
    return defaultScheme + url;
};

var linkifier = exports.linkifier = function linkifier(text) {
    var props = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var renderer = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'a';

    var result = [];
    var parts = text.split(RE_CAPTURE_URLS);
    var keyIndex = 0;
    var keyBase = props.key || defaultKeyBase;
    parts.forEach(function (part) {
        if (!part) {
            return;
        }
        keyIndex++;
        var combinedProps = _extends({}, props);
        var key = keyBase + '-' + keyIndex;
        if (RE_CAPTURE_URLS.test(part)) {
            combinedProps.href = addSchemeIfNeeded(part);
            combinedProps.key = key;
            result.push(React.createElement(renderer, combinedProps, part));
        } else {
            result.push(React.createElement('span', { key: key }, part));
        }
    });
    return result;
};

var IGNORED_TYPES = { 'a': 1, 'button': 1 };

var Linkifier = React.createClass({

    keyIndex: 0,

    linkify: function linkify(children, _ref) {
        var _this = this;

        var target = _ref.target,
            key = _ref.key;

        var keyBase = key || defaultKeyBase;
        if (typeof children === 'string') {
            return linkifier(children, { target: target, key: key }, this.props.renderer);
        }
        if (Array.isArray(children)) {
            return children.map(function (child) {
                return _this.linkify(child, { target: target, key: key });
            });
        }
        if (children && IGNORED_TYPES[children.type]) {
            return children;
        }
        if (React.isValidElement(children)) {
            return React.cloneElement(children, { key: keyBase + '-' + ++this.keyIndex }, this.linkify(children.props.children, { target: target, key: key }));
        }
        return null;
    },
    render: function render() {
        this.keyIndex = 0;

        var _props = this.props,
            children = _props.children,
            target = _props.target,
            keyBase = _props.keyBase,
            _props$wrap = _props.wrap,
            wrap = _props$wrap === undefined ? 'span' : _props$wrap,
            renderer = _props.renderer,
            props = _objectWithoutProperties(_props, ['children', 'target', 'keyBase', 'wrap', 'renderer']);

        return React.createElement.apply(React, [wrap, props].concat(_toConsumableArray(this.linkify(React.Children.toArray(children), { target: target, key: keyBase }))));
    }
});

exports.default = Linkifier;